tui

package
v0.1.7 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 29, 2026 License: MIT Imports: 10 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func ColorForIndex

func ColorForIndex(i int) lipgloss.Color

ColorForIndex returns the Lip Gloss color for a task index (cycles).

func LabelStyle

func LabelStyle(i int) lipgloss.Style

LabelStyle returns a styled rendering function for a task's label.

func StatusDot

func StatusDot(i int, running bool) string

StatusDot returns a colored dot for the task status.

Types

type ClearURLsMsg added in v0.1.4

type ClearURLsMsg struct{ Label string }

ClearURLsMsg clears pinned URLs for a specific task label. If Label is empty, all URLs are cleared.

type Model

type Model struct {
	// contains filtered or unexported fields
}

Model is the Bubble Tea model for the taskr TUI.

func NewModel

func NewModel(r *runner.Runner, watchToggle func(string) bool, watchEnabled func(string) bool) Model

NewModel creates the TUI model.

func (Model) Init

func (m Model) Init() tea.Cmd

Init implements tea.Model.

func (Model) Update

func (m Model) Update(msg tea.Msg) (tea.Model, tea.Cmd)

Update implements tea.Model.

func (Model) View

func (m Model) View() string

View implements tea.Model.

type ReloadMsg added in v0.1.4

type ReloadMsg struct{ Labels []string }

ReloadMsg is sent to the TUI when tasks.json is reloaded so the tab bar, URL bar and task index are updated to reflect the new set of running tasks.

Jump to