Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func ColorForIndex ¶
ColorForIndex returns the Lip Gloss color for a task index (cycles).
func LabelStyle ¶
LabelStyle returns a styled rendering function for a task's label.
Types ¶
type ClearURLsMsg ¶ added in v0.1.4
type ClearURLsMsg struct{ Label string }
ClearURLsMsg clears pinned URLs for a specific task label. If Label is empty, all URLs are cleared.
type Model ¶
type Model struct {
// contains filtered or unexported fields
}
Model is the Bubble Tea model for the taskr TUI.
func NewModel ¶
func NewModel(r *runner.Runner, watchToggle func(string) bool, watchEnabled func(string) bool) Model
NewModel creates the TUI model.
Click to show internal directories.
Click to hide internal directories.